@@ -9,9 +9,7 @@ ncoord <- function(xd, clvecd, nn=50, weighted=FALSE,
     sphere <- "matrix"
   }
   if (sphere!="none"){
-    if (as.numeric(R.version$major)<=1 & as.numeric(R.version$minor)<9)
-      require(lqs)
-    else require(MASS)
+  require(MASS)
     if (sphere=="matrix")
       Sig <- cv
     else
@@ -72,9 +70,7 @@ ncoord <- function(xd, clvecd, nn=50, weighted=FALSE,
 # nearest neighbor pooled linear dimension reduction 
 ancoord <- function(xd, clvecd, clnum=1, nn=50, method="mcd",
                     countmode=1000, ...){
-  if (as.numeric(R.version$major)<=1 & as.numeric(R.version$minor)<9)
-      require(lqs)
-  else require(MASS)
+  require(MASS)
   x <- as.matrix(xd)
   p <- ncol(x)
   n <- nrow(x)
@@ -140,9 +136,7 @@ mvdcoord <- function(xd, clvecd, clnum=1, sphere="mcd", ...){
     cv <- sphere
     sphere="matrix"
   }
-  if (as.numeric(R.version$major)<=1 & as.numeric(R.version$minor)<9)
-      require(lqs)
-  else require(MASS)
+  require(MASS)
   if (sphere!="none"){
     if (sphere=="matrix")
       Sig <- cv
@@ -242,9 +236,7 @@ awcoord <- function(xd, clvecd, clnum=1, mahal="square", method="classical",
                      clweight=switch(method,classical=FALSE,TRUE), alpha=0.99,
                      subsample=0, countmode=1000, ...) {
   x <- as.matrix(xd)
-  if (as.numeric(R.version$major)<=1 & as.numeric(R.version$minor)<9)
-      require(lqs)
-  else require(MASS)
+  require(MASS)
   n <- nrow(x)
   p <- ncol(x)
   dcl <- as.integer(clnum)
